from pylaunch.roku.main import Roku

# Possible keypress values
HOME = "Home"
REVERSE = "Rev"
FORWARD = "Fwd"
PLAY = "Play"
SELECT = "Select"
LEFT = "Left"
RIGHT = "Right"
DOWN = "Down"
UP = "Up"
BACK = "Back"
INSTANT_REPLAY = "InstantReplay"
INFO = "Info"
BACKSPACE = "Backspace"
SEARCH = "Search"
Enter = "Enter"
POWER = "Power"
POWER_ON = "PowerOn"
POWER_OFF = "PowerOn"
VOLUME_UP = "VolumeUp"
VOLUME_DOWN = "VolumeDown"
MUTE = "VolumeMute"
CHANNEL_UP = "ChannelUp"
CHANNEL_DOWN = "ChannelDown"
